---
title: 하이픈 채널설정방법
category: 결제서비스 (채널설정 및 이용안내) > 채널설정 > 채널설정
tags:
  - 계좌간편결제
pgCompanies:
  - 하이픈
searchTags:
  - 간편결제
  - 계좌
  - 계좌 간편 결제
  - 하이픈
datetime: 2024-09-24T05:34:37.935Z
---

<Callout content="결제 연동을 위한 채널 설정 방법을 안내해 드립니다.
결제 연동을 위해서 채널설정은 필수이며 결제대행사와 연동방식별로 설정하는 정보는 상이할 수 있습니다.
또한 채널 설정 없이 결제 연동을 하실 경우 정상적인 호출이 불가하며, 오류가 발생됩니다." />

<Callout content="[가능한 결제수단]
- 간편결제
하이픈은 계좌 간편 결제를 전용으로 지원하는 PG사로, 등록한 계좌를 이용한 결제만 가능하며 다른 결제 수단은 지원하지 않습니다. 

따라서,  payMethod 파라미터를 아래와 같이 설정해야 합니다. 
- 간편결제 : EASY_PAY
" title="참고사항" icon="💡" />

## <Highlight text="계좌 간편 결제란?" />

- 고객이 PG사에서 제공하는 결제 페이지에서 본인 명의의 계좌를 등록하고, 상품 구매 시 비밀번호 인증 등을 통해 등록 된 계좌에서 출금하여 결제하는 서비스를 의미합니다.
- 계좌 간편 결제의 장점\
  계좌 간편 결제는 아래와 같은 장점을 제공합니다.

1. 우수한 사용성\
   보안 프로그램이나 추가 앱 설치 과정이 필요하지 않습니다. 또한 복잡한 계좌 입력이나 인증 과정 없이 최초 한 번만 계좌를 등록하고 이후에는 비밀번호를 통해 간편하게 인증할 수 있습니다.
2. 낮은수수료\
   바로 계좌 결제는 오픈 뱅킹 기반의 계좌 이체 서비스로, 신용카드 결제에 비해 낮은 수수료로 해당 서비스를 이용할 수 있습니다.
3. 빠른 정산 주기\
   하이픈의 계좌 간편 결제 서비스는 통상 D+2일 주기로 정산을 해드리고 있습니다. 빠른 정산을 통해 현금 흐름을 효율적으로 관리할 수 있습니다.

### **테스트 연동**

결제대행사와 계약 전에 미리 연동/개발이 가능한 테스트 연동환경입니다. 테스트 연동은 기본적인 결제 로직을 구현하실 수 있도록 미리 제공되는 범용적인 Key 입니다. 보다 자세한 테스트 연동 환경의 특징은 아래 가이드를 자세히 참조해주세요.

- [테스트 연동 특징 바로가기↗](https://help.portone.io/category/procedure/payment-integration/test?page=1)

<Callout content="하이픈의 경우 
테스트용  MID/연동키는 고객사에서 하이픈 계약시 발급받아 세팅/연동 가능함." title="참고사항" icon="💡" />



#### **설정경로**

- [포트원 관리자콘솔↗](https://admin.portone.io/) > 결제 연동 > 채널관리 > + 채널 추가
  - 연동 모드 : 테스트 연동
  - 결제대행사 : 하이픈
  - 결제모듈 : 간편결제(계좌이체): 바로계좌결제

#### **설정방법**

- 채널 이름 : 상점 정보만으로는 채널(PG)의 성격을 파악하기 어려워 채널(PG)의 이름을 설정하는 용도로 구분하기 위한 필수 설정값으로 임의값으로 설정이 가능합니다(단, 숫자, 공백, 글자, \_, - 만 가능)
- 채널 속성 : 결제
- PG상점아이디 (상점번호) 클릭
  - 테스트용  MID/연동키는 하이픈 계약시 발급받아 세팅/연동 가능함.
- 암호화 키 / 토큰\
  하이픈 계약시 발급받아 세팅/연동 가능함.
- 과세설정 : [포트원 결제사정산 서비스↗ ](https://admin.portone.io/reconciliation/summary)이용시 단순 과세계산을 위해 사용되는 항목으로 미 이용시 설정하지 않으셔도 무방합니다. 거래의 과세/면세 여부와는 관계없습니다.

### **실 연동**

결제대행사와의 모든 계약을 마친 후 원천사(카드사. 은행 등)의 심사가 진행됩니다. 실 연동을 위한 특징은 아래 가이드를 통해 확인하실 수 있습니다.

- [실 연동 특징 보러가기↗](https://help.portone.io/category/procedure/payment-integration/real?page=1)

<Callout content="하이픈은 계좌 간편 결제를 전용으로 지원하는 PG사로, 등록한 계좌를 이용한 결제만 가능하며 다른 결제 수단은 지원하지 않습니다.
따라서 payMethod 파라미터를 아래와 같이 설정해야 합니다.
※ 간편결제 : EASY_PAY" title="참고사항" icon="💡" />



#### **설정경로**

- [포트원 관리자콘솔↗](https://admin.portone.io/) > 결제 연동 > 채널관리 > + 채널 추가
  - 연동 모드 : 실 연동
  - 결제대행사 : 하이픈
  - 결제모듈 : 간편결제(계좌이체) ,바로계좌결제

#### **설정방법**

- 채널 이름 : 상점 정보만으로는 채널(PG)의 성격을 파악하기 어려워 채널(PG)의 이름을 설정하는 용도로 구분하기 위한 필수 설정값으로 임의값으로 설정이 가능합니다(단, 숫자, 공백, 글자, \_, - 만 가능)
- 채널 속성 : 결제
- PG상점아이디 (상점번호) 클릭 : 하이픈과 계약 후 발급받은 상점아이디 (상점번호)
- 과세설정 : [포트원 결제사정산 서비스↗ ](https://admin.portone.io/reconciliation/summary)이용시 단순 과세계산을 위해 사용되는 항목으로 미 이용시 설정하지 않으셔도 무방합니다. 거래의 과세/면세 여부와는 관계없습니다.

<Callout title="하이픈 개발가이드 보러가기↗" />
